@@ -4,6 +4,8 @@
 
 from ._lightgbm import CrossLightgbmModel
 from ._xgboost import CrossXgboostModel
+from ._catboost import CrossCatboostModel
 
 __all__ = ['CrossLightgbmModel',
-           'CrossXgboostModel']
\ No newline at end of file
+           'CrossXgboostModel',
+           'CrossCatboostModel']
