@@ -82,10 +82,10 @@ class CrossModelFabric(ABC):
             y_train, y_val = train[self.col_target], val[self.col_target]
 
             dtrain = self.get_dataset(
-                data=X_train.astype(float),
+                data=X_train,
                 label=y_train,
                 categorical_feature=self.cols_cat)
-            dvalid = self.get_dataset(data=X_val.astype(float), label=y_val,
+            dvalid = self.get_dataset(data=X_val, label=y_val,
                                       categorical_feature=self.cols_cat)
 
             if fold % self.iterator.n_splits == 0:
@@ -115,11 +115,11 @@ class CrossModelFabric(ABC):
             self.models[fold] = model
             if self.valid:
                 # Построение прогнозов при разном виде взаимодействия
-                scores[fold] = evals_result['eval']['auc']
-                best_auc = np.max(evals_result['eval']['auc'])
+                scores[fold] = evals_result['eval'][self.params['metric']]
+                best_auc = np.max(evals_result['eval'][self.params['metric']])
                 scores_avg.append(best_auc)
 
-                log.info(f'\tCROSSVALIDATION FOLD {fold%self.iterator.n_splits} ENDS with best ROCAUC = {best_auc}')
+                log.info(f'\tCROSSVALIDATION FOLD {fold%self.iterator.n_splits} ENDS with best `{self.params["metric"]}` = {best_auc}')
 
         if self.valid:
             self.scores = pd.DataFrame(
@@ -162,7 +162,7 @@ class CrossModelFabric(ABC):
             # Подготовка данных в нужном формате
             model = self.models[fold]
             predict.loc[X_val.index] += \
-                model.predict(X_val[model.feature_name()].astype(float),
+                model.predict(X_val[model.feature_name()],
                               num_iteration=self.num_boost_optimal) / self.iterator.n_repeats
 
         return predict
@@ -177,13 +177,18 @@ class CrossModelFabric(ABC):
 
         for fold in self.models.keys():
             model = self.models[fold]
-            predict += model.predict(test[model.feature_name()].astype(
-                float), num_iteration=self.num_boost_optimal) / models_len
+            predict += model.predict(test[model.feature_name()], num_iteration=self.num_boost_optimal) / models_len
 
         return predict
 
-    def shap(self, df: pd.DataFrame):
-        fig = plt.figure(figsize=(10, 10))
+    def shap(self, df: pd.DataFrame, n_samples=500, figsize=(10, 10)):
+        '''
+
+        :param df:
+        :param n_samples: количество записей которое будет семплироваться в каждом тестовом фолде для анализы shap values
+        :return:
+        '''
+        fig = plt.figure(figsize=figsize)
         log = logging.getLogger(__name__)
         shap_df_fin = pd.DataFrame(columns=['feature'])
 
@@ -203,8 +208,11 @@ class CrossModelFabric(ABC):
             model = self.models[fold]
             explainer = shap.TreeExplainer(model)
             df_sample = X_val[model.feature_name()].sample(
-                n=500, random_state=0, replace=True).astype(float)
-            shap_values = explainer.shap_values(df_sample)[1]
+                n=n_samples, random_state=0, replace=True)
+            if self.params['metric']=='auc':
+                shap_values = explainer.shap_values(df_sample)[1]
+            else:
+                shap_values = explainer.shap_values(df_sample)
             shap_df = pd.DataFrame(zip(model.feature_name(), np.mean(
                 np.abs(shap_values), axis=0)), columns=['feature', 'shap_' + str(fold)])
             shap_df_fin = pd.merge(shap_df_fin, shap_df,
@@ -223,7 +231,7 @@ class CrossModelFabric(ABC):
                     estimator=np.mean, order=cols_best)
         return fig, shap_feature_stats.reset_index()
 
-    def shap_summary_plot(self, test: pd.DataFrame):
+    def shap_summary_plot(self, test: pd.DataFrame, n_samples=500):
         fig = plt.figure()
         log = logging.getLogger(__name__)
         shap_df_fin = pd.DataFrame(columns=['feature'])
@@ -235,8 +243,11 @@ class CrossModelFabric(ABC):
         model = self.models[0]
         explainer = shap.TreeExplainer(model)
         df_sample = test[model.feature_name()].sample(
-            n=500, random_state=0, replace=True).astype(float)
-        shap_values = explainer.shap_values(df_sample)[1]
+            n=n_samples, random_state=0, replace=True)
+        if self.params['metric']=='auc':
+            shap_values = explainer.shap_values(df_sample)[1]
+        else:
+            shap_values = explainer.shap_values(df_sample)
         shap_df = pd.DataFrame(zip(model.feature_name(), np.mean(
             np.abs(shap_values), axis=0)), columns=['feature', 'shap_'])
         shap_df_fin = pd.merge(shap_df_fin, shap_df, how='outer', on='feature')
